blob 1.2.3

## Cran Repository Policy

- [x] Reviewed CRP last edited 2022-02-08.

## R CMD check results

- [x] Checked locally, R 4.1.2
- [x] Checked on CI system, R 4.1.3
- [x] Checked on win-builder, R devel

## Current CRAN check results

- [x] Checked on 2022-04-10, no problems found.
